### Contributing Guidelines

---

# Contributing to Gula DAO

We love your input! We want to make contributing to this project as easy and transparent as possible, whether it's:

- Reporting a bug
- Discussing the current state of the code
- Submitting a fix
- Proposing new features

## We Develop with GitHub

We use GitHub to host code, to track issues and feature requests, as well as accept pull requests.

## We Use [GitHub Flow](https://guides.github.com/introduction/flow/index.html), So All Code Changes Happen Through Pull Requests

Pull requests are the best way to propose changes to the codebase (we use [GitHub Flow](https://guides.github.com/introduction/flow/index.html)). We actively welcome your pull requests:

1. Fork the repo and create your branch from `main`.
2. If you've added code that should be tested, add tests.
3. If you've changed APIs, update the documentation.
4. Ensure the test suite passes.
5. Make sure your code lints.
6. Issue that pull request!

## Any contributions you make will be under the MIT Software License

In short, when you submit code changes, your submissions are understood to be under the same [MIT License](LICENSE) that covers the project. Feel free to contact the maintainers if that's a concern.

## Report bugs using GitHub's [issues](https://github.com/gulagulali404/Gula-DAO/issues)

We use GitHub issues to track public bugs. Report a bug by [opening a new issue](https://github.com/gulagulali404/Gula-DAO/issues); it's that easy!

## Write bug reports with detail, background, and sample code

Here's an example of a good bug report:

> **Bad**:
> There's a bug.

> **Good**:
> There's a bug in the login function. It doesn't return an error if the username is missing.
>
> **Steps to reproduce**:
> 1. Open the login page.
> 2. Click the login button without entering a username.
> 3. No error message is displayed.

## Use a Consistent Coding Style

* 4 spaces for indentation rather than tabs
* You can try running `npm run lint` for style issues.

## License

By contributing, you agree that your contributions will be licensed under its MIT License.
